@@ -6,6 +6,8 @@ import torch
 from rust_circuit import Einsum, ScalarConstant, ArrayConstant, Symbol, Add, Rearrange, RearrangeSpec, Concat, Index
 
 # %%
+e = Einsum.from_einsum_string("a->", [ScalarConstant(0.2, (2,))])
+e.compiler_print()
 
 x = Einsum(
     (ScalarConstant(0.2), ()),
