@@ -360,7 +360,7 @@ impl RearrangeSpec {
                     }
                 };
                 let mut handle_string = |string: String, sizes: &mut OpShape| -> Option<u8> {
-                    if let [string, num] = string.split(":").collect::<Vec<_>>()[..] {
+                    if let [string, num] = string.split(':').collect::<Vec<_>>()[..] {
                         let num = num.parse::<usize>().ok()?;
                         let result = handle_string_nosize(string.to_owned(), sizes);
                         sizes[result as usize] = Some(num).into();
@@ -539,8 +539,7 @@ impl RearrangeSpec {
     #[args(special_case_ones = true)]
     pub fn canonicalize(&self, special_case_ones: bool) -> Self {
         // Remove all indices of size 1
-        let int_sizes: Vec<Option<usize>> =
-            self.int_sizes.iter().map(|x| x.clone().into()).collect();
+        let int_sizes: Vec<Option<usize>> = self.int_sizes.iter().map(|x| (*x).into()).collect();
         let mut input_ints = self.input_ints.clone();
         let mut output_ints = self.output_ints.clone();
         if special_case_ones {
@@ -628,7 +627,7 @@ impl RearrangeSpec {
                             let new_i: u8 = new_int_sizes.len().try_into().unwrap();
                             map.insert(i, new_i);
                             new_dim.push(new_i);
-                            new_int_sizes.push(int_sizes[i as usize].clone().into());
+                            new_int_sizes.push(int_sizes[i as usize].into());
                         } else if !already_accounted_shape[i as usize] {
                             if let Some(old_size) = int_sizes[i as usize] {
                                 let new_int_sizes_idx =
