@@ -15,17 +15,17 @@ pub type EinInt = u8;
 #[apply(make_lazy)]
 #[lazy_ty(Lazy)]
 pub fn alphabet() -> Vec<String> {
-    let alphabet_upper: Vec<String> = (b'A'..=b'Z')
-        .map(|x| std::str::from_utf8(&[x]).unwrap().to_owned())
-        .collect();
-    let alphabet_lower: Vec<String> = (b'a'..=b'z')
-        .map(|x| std::str::from_utf8(&[x]).unwrap().to_owned())
-        .collect();
-    alphabet_lower
+    let alphabet_upper: Vec<String> = ('A'..'[').map(|x| x.to_string()).collect(); // char after Z
+    let alphabet_lower: Vec<String> = ('a'..'{').map(|x| x.to_string()).collect();
+    let alphabet_greek_lower: Vec<String> = ('α'..'ω').map(|x| x.to_string()).collect();
+    let result = alphabet_lower
         .iter()
         .chain(alphabet_upper.iter())
+        .chain(alphabet_greek_lower.iter())
         .cloned()
-        .collect()
+        .collect();
+    dbg!(&result);
+    result
 }
 
 #[apply(make_lazy)]
