@@ -14,20 +14,19 @@ fn benchmarking_circs() {
         pyo3::prepare_freethreaded_python();
 
         dbg!("pre");
-        let circuits: Vec<_> =
-            fs::read_dir(format!("{}/ryan/compiler_benches/", get_rrfs_dir()))
-                .unwrap()
-                .map(|d| {
-                    parse_compiler_repr_bijection(
-                        &fs::read_to_string(d.unwrap().path()).unwrap(),
-                        Default::default(),
-                        Default::default(),
-                        false,
-                        Default::default(),
-                    )
-                    .unwrap()
-                })
-                .collect();
+        let circuits: Vec<_> = fs::read_dir(format!("{}/ryan/compiler_benches/", get_rrfs_dir()))
+            .unwrap()
+            .filter_map(|d| {
+                parse_compiler_repr_bijection(
+                    &fs::read_to_string(d.unwrap().path()).unwrap(),
+                    Default::default(),
+                    Default::default(),
+                    true,
+                    Default::default(),
+                )
+                .ok()
+            })
+            .collect();
         dbg!("post");
 
         let mut settings: OptimizationSettings = Default::default();
